#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 what4
version:              1.6
visibility:           public
id:                   what4-1.6-BFsIHz7oWP16O368xg7lXg
key:                  what4-1.6-BFsIHz7oWP16O368xg7lXg
license:              BSD-3-Clause
copyright:            (c) Galois, Inc 2014-2023
maintainer:           rscott@galois.com, kquick@galois.com
author:               Galois Inc.
homepage:             https://github.com/GaloisInc/what4
synopsis:             Solver-agnostic symbolic values support for issuing queries
description:
    What4 is a generic library for representing values as symbolic formulae which may
    contain references to symbolic values, representing unknown variables.
    It provides support for communicating with a variety of SAT and SMT solvers,
    including Z3, CVC4, CVC5, Yices, Bitwuzla, Boolector, STP, and dReal.
    The data representation types make heavy use of GADT-style type indices
    to ensure type-correct manipulation of symbolic values.

category:             Formal Methods, Theorem Provers, Symbolic Computation, SMT
abi:                  9d60ca3032107b890a438bced2532531
exposed:              True
exposed-modules:
    Test.Verification What4.BaseTypes What4.Concrete What4.Config
    What4.Expr What4.Expr.Allocator What4.Expr.App What4.Expr.AppTheory
    What4.Expr.ArrayUpdateMap What4.Expr.BoolMap What4.Expr.Builder
    What4.Expr.GroundEval What4.Expr.MATLAB What4.Expr.Simplify
    What4.Expr.StringSeq What4.Expr.UnaryBV
    What4.Expr.VarIdentification What4.Expr.WeightedSum What4.FloatMode
    What4.FunctionName What4.IndexLit What4.Interface
    What4.InterpretedFloatingPoint What4.LabeledPred What4.Panic
    What4.Partial What4.ProblemFeatures What4.ProgramLoc
    What4.Protocol.Online What4.Protocol.PolyRoot
    What4.Protocol.ReadDecimal What4.Protocol.SExp
    What4.Protocol.SMTLib2 What4.Protocol.SMTLib2.Parse
    What4.Protocol.SMTLib2.Response What4.Protocol.SMTLib2.Syntax
    What4.Protocol.SMTWriter What4.Protocol.VerilogWriter
    What4.Protocol.VerilogWriter.ABCVerilog
    What4.Protocol.VerilogWriter.AST
    What4.Protocol.VerilogWriter.Backend What4.SFloat What4.SWord
    What4.SatResult What4.SemiRing What4.Serialize.FastSExpr
    What4.Serialize.Log What4.Serialize.Normalize
    What4.Serialize.Parser What4.Serialize.Printer
    What4.Serialize.SETokens What4.Solver What4.Solver.Adapter
    What4.Solver.Bitwuzla What4.Solver.Boolector What4.Solver.CVC4
    What4.Solver.CVC5 What4.Solver.DReal What4.Solver.ExternalABC
    What4.Solver.STP What4.Solver.Yices What4.Solver.Z3
    What4.SpecialFunctions What4.Symbol What4.Utils.AbstractDomains
    What4.Utils.AnnotatedMap What4.Utils.Arithmetic
    What4.Utils.BVDomain What4.Utils.BVDomain.Arith
    What4.Utils.BVDomain.Bitwise What4.Utils.BVDomain.XOR
    What4.Utils.Complex What4.Utils.Endian What4.Utils.Environment
    What4.Utils.FloatHelpers What4.Utils.HandleReader
    What4.Utils.IncrHash What4.Utils.LeqMap What4.Utils.MonadST
    What4.Utils.OnlyIntRepr What4.Utils.Process
    What4.Utils.ResolveBounds.BV What4.Utils.Serialize
    What4.Utils.Streams What4.Utils.StringLiteral What4.Utils.Versions
    What4.Utils.Word16String What4.WordMap

import-dirs:          /usr/lib/ghc-9.6.6/site-local/what4-1.6
library-dirs:         /usr/lib/ghc-9.6.6/site-local/what4-1.6
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/what4-1.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-what4
hs-libraries:         HSwhat4-1.6-BFsIHz7oWP16O368xg7lXg
depends:
    BoundedChan-1.0.3.0-KC4GwTTdtFBGyIaMAN8c52
    async-2.2.6-HlTb8qs1wHD7UNlnrqlxTX
    attoparsec-0.14.4-8ZKlPX7xLQdALFlvUv2KV7 base-4.18.2.1
    bifunctors-5.6.3-LIHzRn6X9Du95aif640rEj
    bimap-0.5.0-Iviz8NQbsvUCWrR75JBvUB
    bv-sized-1.0.6-FSxfVDIm9FkAh6VMuB7PES bytestring-0.11.5.3
    concurrent-extra-0.7.0.12-FKe59XoXb8mKDalLJJcez6
    config-value-0.8.3-IWIlPmbx9u07ZPnTUBDeDU containers-0.6.7
    deepseq-1.4.8.1 deriving-compat-0.6.8-4vz1VrW7DyC3cK79T9oTty
    directory-1.3.8.5 exceptions-0.10.7 filepath-1.4.300.1
    fingertree-0.1.6.2-88bGPzYXU7321HeCwWt9vv ghc-prim-0.10.0
    hashable-1.4.7.0-3mscVqjFvnNHNJmw9rQ9m6
    hashtables-1.4.2-JZE0Pk9GRJlKbiY0Pedl9p
    io-streams-1.5.2.2-Ju8ZwriFWIeB5oSMpwZIo7
    lens-5.3.4-59xiJiOdHtvHZvlFC0zvFo
    libBF-0.6.7-1FnU0F9v8ukAsEaS3EMoTx
    megaparsec-9.7.0-LsMZWhtkE3fBVBzlHYNPEo mtl-2.3.1
    ordered-containers-0.2.4-ImUdrVTsBhxEVDyDO6i1HV
    panic-0.4.0.1-LjSerD2Hu1fK37HhFAQEbK
    parameterized-utils-2.1.11.0-AHS46NP08ikAOtvYLC5Sf6 parsec-3.1.16.1
    prettyprinter-1.7.1-2nVenIIUlIN10A4pxpSujW process-1.6.19.0
    s-cargot-0.1.6.0-7bB2MNOCdd8HKFlANqnD0o
    scientific-0.3.8.1-6eIXfo5Wftk14zLbUcezxx stm-2.5.1.0
    template-haskell-2.20.0.0 temporary-1.3-EZyCN0IpTQNJIMCpUwiknJ
    text-2.0.2 th-lift-0.8.6-259dLbfPJk9HrfYIeZHdvQ
    th-lift-instances-0.1.20-8XklgV9Q93PyAxl60BeUJ time-1.12.2
    transformers-0.6.1.0 unliftio-0.2.25.1-2YWCJQ4bXOaKV2dFmJlGMH
    unordered-containers-0.2.20.1-CeHDQtVso2t69dwLJnxrjh
    utf8-string-1.0.2-GrV0vD7epd2Fw38ZtPT1hv
    vector-0.13.2.0-2vFNmgih5WRFjWzUm3LR1R
    versions-6.0.8-EorQ5vWytfm1CUwGvVe4uh
    zenc-0.1.2-G4skmsi3LvL4yN84bZeRL

haddock-interfaces:   /usr/share/doc/haskell-what4/html/what4.haddock
haddock-html:         /usr/share/doc/haskell-what4/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

